package osgi.impl;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import Ice.InitializationData;
import Ice.Properties;

public class HelloAdapterServer extends Ice.Application {
	private HelloI helloI;
	protected Log logger = LogFactory.getLog(HelloAdapterServer.class);
	private String defaultLocator = "OkoooGrid/Locator:default -h grid.registry.com -p 4061";
	private String adapterId = "HelloServer169.HelloAdapter";
	private String endPoints = "tcp";
	private String serverId = "HelloServer169";
	private String programName = "HelloServer169";
	private String replicaGroupId = "HelloRepGroup";

	private String objectId = "HelloObject";
	private Ice.ObjectAdapter helloAdapter;

	public void start() {
		new Thread(new Runnable() {
			@Override
			public void run() {
				try {
					Properties props = Ice.Util.createProperties();
					props.setProperty("Ice.Default.Locator", defaultLocator);
					props.setProperty("Ice.ServerId", serverId);
					props.setProperty("Ice.ProgramName", programName);
					props.setProperty("HelloAdapter.ReplicaGroupId",
							replicaGroupId);
					props.setProperty("HelloAdapter.RegisterProcess", "0");
					props.setProperty("HelloAdapter.AdapterId", adapterId);
					props.setProperty("HelloAdapter.Endpoints", endPoints);
					InitializationData id = new InitializationData();
					id.properties = props;
					main("HelloAdapterServer", new String[] {}, id);
				} catch (Exception e) {
					logger.error("", e);
				}
			}
		}).start();
	}

	public int run(String[] args) {
		logger.info("trying to start hello adapter server...");
		helloAdapter = communicator().createObjectAdapter("HelloAdapter");
		Ice.Identity helloObjectId = communicator().stringToIdentity(objectId);
		helloAdapter.add(helloI, helloObjectId);
		helloAdapter.activate();
		logger.info("HelloServer start OK.");
		communicator().waitForShutdown();
		return 0;
	}

	public void stop() {
		logger.info("trying to stop hello adapter server...");
		communicator().shutdown();
		logger.info("shutdown ok");
	}

	public HelloI getHelloI() {
		return helloI;
	}

	public void setHelloI(HelloI helloI) {
		this.helloI = helloI;
	}

	public String getDefaultLocator() {
		return defaultLocator;
	}

	public void setDefaultLocator(String defaultLocator) {
		this.defaultLocator = defaultLocator;
	}

	public String getAdapterId() {
		return adapterId;
	}

	public void setAdapterId(String adapterId) {
		this.adapterId = adapterId;
	}

	public String getEndPoints() {
		return endPoints;
	}

	public void setEndPoints(String endPoints) {
		this.endPoints = endPoints;
	}

	public String getObjectId() {
		return objectId;
	}

	public void setObjectId(String objectId) {
		this.objectId = objectId;
	}

	public String getServerId() {
		return serverId;
	}

	public void setServerId(String serverId) {
		this.serverId = serverId;
	}

	public String getProgramName() {
		return programName;
	}

	public void setProgramName(String programName) {
		this.programName = programName;
	}

	public String getReplicaGroupId() {
		return replicaGroupId;
	}

	public void setReplicaGroupId(String replicaGroupId) {
		this.replicaGroupId = replicaGroupId;
	}

}
